@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: chroot-startstop.sh 2809 2009-07-12 17:27:50Z eldering $
+# $Id: chroot-startstop.sh 3202 2010-06-06 23:19:53Z eldering $
 
 # Script to setup chroot environment extras needed for Sun Java.
 #
@@ -28,8 +28,15 @@ case "$1" in
 		sudo -S mount -n -t proc --bind /proc proc < /dev/null
 
 		for i in $SUBDIRMOUNTS ; do
-			mkdir -p $i
-			sudo -S mount --bind "$CHROOTORIGINAL/$i" $i < /dev/null
+
+			# Some dirs may be links to others, e.g. /lib64 -> /lib.
+			# Preserve those; bind mount the others.
+			if [ -L "$CHROOTORIGINAL/$i" ]; then
+				ln -s `readlink "$CHROOTORIGINAL/$i"` $i
+			else
+				mkdir -p $i
+				sudo -S mount --bind "$CHROOTORIGINAL/$i" $i < /dev/null
+			fi
 		done
 		;;
 
@@ -41,8 +48,12 @@ case "$1" in
 		sudo -S umount "$PWD/proc" < /dev/null
 
 		for i in $SUBDIRMOUNTS ; do
-			sudo -S umount "$PWD/$i" < /dev/null
-			rmdir $i || true
+			if [ -L "$CHROOTORIGINAL/$i" ]; then
+				rm -f $i
+			else
+				sudo -S umount "$PWD/$i" < /dev/null
+				rmdir $i || true
+			fi
 		done
 		;;
 
