@@ -3,7 +3,7 @@
  *
  * Based on submit.pl by Eelco Dolstra.
  *  
- * $Id: submit.cc 2696 2009-05-16 18:48:13Z eldering $
+ * $Id: submit.cc 3233 2010-07-08 07:58:56Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -346,9 +346,9 @@ int main(int argc, char **argv)
 	if ( team.empty()     ) usage2(0,"no team specified");
 	
 	if (use_websubmit) {
-		if ( server.empty()  ) usage2(0,"no server specified");
-	} else {
 		if ( baseurl.empty() ) usage2(0,"no url specified");
+	} else {
+		if ( server.empty() ) usage2(0,"no server specified");
 	}
 
 	logmsg(LOG_DEBUG,"problem is `%s'",problem.c_str());
@@ -551,20 +551,23 @@ int file_istext(char *filename)
 {
 	magic_t cookie;
 	const char *filetype;
+	int res;
 
-	if ( (cookie = magic_open(MAGIC_MIME))==NULL ) goto error;
+	if ( (cookie = magic_open(MAGIC_MIME))==NULL ) goto magicerror;
 
-	if ( magic_load(cookie,NULL)!=0 ) goto error;
-	
-	if ( (filetype = magic_file(cookie,filename))==NULL ) goto error;
+	if ( magic_load(cookie,NULL)!=0 ) goto magicerror;
+
+	if ( (filetype = magic_file(cookie,filename))==NULL ) goto magicerror;
 
 	logmsg(LOG_DEBUG,"mime-type of '%s'",filetype);
-	
+
+	res = ( strncmp(filetype,"text/",5)==0 );
+
 	magic_close(cookie);
 
-	return strncmp(filetype,"text/",5)==0;
+	return res;
 
-error:
+magicerror:
 	warning(magic_errno(cookie),magic_error(cookie));
 
 	return 1; // return 'text' by default on error
