@@ -2,7 +2,7 @@
 /**
  * View of one contest.
  *
- * $Id: contest.php 2843 2009-07-14 22:12:38Z kink $
+ * $Id: contest.php 3169 2010-05-16 15:52:48Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -19,8 +19,8 @@ if ( IS_ADMIN && !empty($_GET['cmd']) ):
 	$cmd = $_GET['cmd'];
 
 	require(LIBWWWDIR . '/forms.php');
-	
-	echo "<h2>" . ucfirst($cmd) . " contest</h2>\n\n";
+
+	echo "<h2>" . htmlspecialchars(ucfirst($cmd)) . " contest</h2>\n\n";
 
 	echo addForm('edit.php');
 
