@@ -2,7 +2,7 @@
 /**
  * View a problem
  *
- * $Id: problem.php 2843 2009-07-14 22:12:38Z kink $
+ * $Id: problem.php 3169 2010-05-16 15:52:48Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -41,7 +41,7 @@ require(LIBWWWDIR . '/forms.php');
 
 if ( IS_ADMIN && !empty($cmd) ):
 	
-	echo "<h2>" . ucfirst($cmd) . " problem</h2>\n\n";
+	echo "<h2>" .  htmlspecialchars(ucfirst($cmd)) . " problem</h2>\n\n";
 
 	echo addForm('edit.php');
 
