@@ -2,7 +2,7 @@
 /**
  * View a row in a team_category
  *
- * $Id: team_category.php 2843 2009-07-14 22:12:38Z kink $
+ * $Id: team_category.php 3169 2010-05-16 15:52:48Z eldering $
  *
  * Part of the DOMjudge Programming Contest Jury System and licenced
  * under the GNU GPL. See README and COPYING for details.
@@ -18,10 +18,10 @@ if ( IS_ADMIN && ($cmd == 'add' || $cmd == 'edit') ) {
 
 	require(LIBWWWDIR . '/forms.php');
 
-	$title = "Category: $cmd";
+	$title = "Category: " . htmlspecialchars($cmd);
 
 	require(LIBWWWDIR . '/header.php');
-	echo "<h2>" . ucfirst($cmd) . " category</h2>\n\n";
+	echo "<h2>" . htmlspecialchars(ucfirst($cmd)) . " category</h2>\n\n";
 
 	echo addForm('edit.php');
 
